#!/bin/sh -e
# tar.gz with project-ver/ in tree debmake (none as default)
LC_ALL=C.UTF-8
export LC_ALL

# non-native source tree with tar.gz on side
PROJECT=foo-3.5
rm -f ${PROJECT}*.tar.?z
rm -rf ${PROJECT}
mkdir ${PROJECT}
echo "DUMMY ${PROJECT}" > ${PROJECT}/dummy-${PROJECT}
tar -cvzf ${PROJECT}.tar.gz ${PROJECT}
cd ${PROJECT} || exit 1
debmake
test -x debian/rules
cd .. || exit 1

